@@ -269,7 +269,7 @@ class Crp:
 
         return output
 
-    def prepareDF(self, df, dateFlag_sep, date_flag_min, lag, items_dataset, customer_name, train_window, sq_pass,
+    def prepareDF(self, df, dateFlag_sep, date_Received Emailflag_min, lag, items_dataset, customer_name, train_window, sq_pass,
                   lastTimeflagParam):
         """
         Params:
